@@ -41,6 +41,8 @@ class RelatedFieldAdmin(ModelAdmin):
 class DetailAdmin(ModelAdmin):
     detail_template = None
     changelist_link_detail = False
+    # prevents django-guardian from clobbering change_form template (Scott)
+    change_form_template = None
 
     def get_changelist(self, request, **kwargs):
         from swingers.admin.views import DetailChangeList
