@@ -5,6 +5,8 @@ from django.conf import settings
 
 from fabric.api import local
 
+import os
+
 
 class Command(NoArgsCommand):
     help = ("Runs `collectstatic --no-input -l` and fixes ownership and "
@@ -24,9 +26,10 @@ class Command(NoArgsCommand):
         call_command("collectstatic", link=link, interactive=False, **options)
         output += local("sudo chmod -R a=rX {0}".format(settings.STATIC_ROOT),
                         capture=True)
-        output += local("sudo chown -RL :www-data {0}".format(
-            settings.MEDIA_ROOT), capture=True)
-        output += local("sudo chmod -R g=rwX {0}".format(settings.MEDIA_ROOT),
-                        capture=True)
+        if os.path.exists(settings.MEDIA_ROOT):
+            output += local("sudo chown -RL :www-data {0}".format(
+                settings.MEDIA_ROOT), capture=True)
+            output += local("sudo chmod -R g=rwX {0}".format(
+                settings.MEDIA_ROOT), capture=True)
 
         self.stderr.write(output)
