@@ -47,7 +47,8 @@ class UpdateCacheMiddleware(DjangoUpdateCacheMiddleware):
     def get_and_set_readtables(self, cache_key):
         read = (self.read_table_regex.finditer(q['sql'])
                 for q in connection.queries
-                if q['sql'].startswith("SELECT"))
+                if (q['sql'].startswith("SELECT") or
+                    q['sql'].startswith('QUERY = u\'SELECT')))
         readtables = []
         for r in itertools.chain(*read):
             if r is not None:
@@ -99,7 +100,8 @@ class UpdateCacheMiddleware(DjangoUpdateCacheMiddleware):
         # flush appropriate parts of the cache
         written = (self.write_table_regex.finditer(q['sql'])
                    for q in connection.queries
-                   if not q['sql'].startswith("SELECT"))
+                   if not (q['sql'].startswith("SELECT") or
+                           q['sql'].startswith('QUERY = u\'SELECT')))
         writtentables = []
         for w in itertools.chain(*written):
             if w is not None:
