@@ -10,12 +10,14 @@ from django.middleware.cache import FetchFromCacheMiddleware
 
 from swingers.middleware.auth import get_exempt_urls, AuthenticationMiddleware
 from swingers.middleware.transaction import ResponseStatusTransactionMiddleware
-from swingers.middleware.cache import UpdateCacheMiddleware
 from swingers.sauth.models import ApplicationLink, Token
 from swingers.tests.models import Duck, Counter
 
 from datetime import timedelta
 
+import unittest2
+import django
+
 
 class AuthenticationMiddlewareTests(TestCase):
     """
@@ -170,6 +172,7 @@ class AuthenticationMiddlewareTests(TestCase):
             self.assertTrue(get_exempt_urls()[1] in settings.LOGIN_EXEMPT_URLS)
 
 
+@unittest2.skipIf(django.VERSION >= (1, 6, 0), 'Not supported in django>=1.6')
 class TransactionMiddlewareTests(TransactionTestCase):
     fixtures = ['test-users']
 
