@@ -4,6 +4,7 @@ from django.middleware.transaction import TransactionMiddleware
 from django.db import transaction
 
 import warnings
+import django
 
 
 ERROR_RESPONSES = [400, 401, 403, 404, 405, 409, 410, 500, 501]
@@ -23,12 +24,15 @@ class ResponseStatusTransactionMiddleware(TransactionMiddleware):
                       PendingDeprecationWarning)
 
     def process_response(self, request, response):
-        """Commits and leaves transaction management."""
-        if transaction.is_managed():
-            if transaction.is_dirty():
-                if response.status_code in ERROR_RESPONSES:
-                    transaction.rollback()
-                else:
-                    transaction.commit()
-            transaction.leave_transaction_management()
+        """Commits and leaves transaction management.
+
+        Does nothing for django>=1.6."""
+        if django.VERSION < (1, 6, 0):
+            if transaction.is_managed():
+                if transaction.is_dirty():
+                    if response.status_code in ERROR_RESPONSES:
+                        transaction.rollback()
+                    else:
+                        transaction.commit()
+                transaction.leave_transaction_management()
         return response
