@@ -1,11 +1,15 @@
 from django.conf.urls import patterns, url
 from django.contrib.auth.views import login
 
-from swingers.tests.views import (create_duck, create_duck2, CreateDuck,
-                                  CreateDuck2)
+from swingers.tests.views import *
+
 
 urlpatterns = patterns(
     'swingers.sauth.views',
+    url(r'^update_counter/(?P<pk>\d+)/$', CounterView.as_view(),
+        name="test-update-counter"),
+    url(r'^update_counter2/(?P<pk>\d+)/$', CounterView.as_view(),
+        name="test-update-counter2"),
     url(r'^create_duck/$', create_duck, name="test-create-duck"),
     url(r'^create_duck2/$', CreateDuck.as_view(),
         name="test-create-duck2"),
